@@ -1,4 +1,5 @@
 import json
+import sys
 
 import requests
 from noteread.legado.shelf.base import BookSource
@@ -11,7 +12,7 @@ def add_source(urls=None):
         return
 
     book = BookSource()
-    logger.info("begin")
+    print(book.db_path)
     for url in tqdm(urls):
         try:
             text = requests.get(url).text
@@ -21,9 +22,6 @@ def add_source(urls=None):
             logger.error(e)
 
 
-
-
-
 urls = [
     "https://namofree.gitee.io/yuedu3/legado3_booksource_by_Namo.json",
     "https://shuyuan.miaogongzi.net/shuyuan/1630342495.json",
